@@ -25,17 +25,23 @@ enum TypeID {
 #define BACKGROUND 5
 
 typedef unsigned int TypeID;
+typedef int ObjID;
 
-class SceneNode : public Node
+#define BBOXID 1
+static ObjID nextID = BBOXID + 1;
+
+class SceneNode
 {
 public:
   inline const TypeID getTypeID() const { return typeID; }
+  inline const ObjID getObjID() const { return objID; }
   virtual ~SceneNode() { };
 protected:
-  SceneNode(const TypeID in_typeID) : typeID(in_typeID) 
-  { };
+  SceneNode(const TypeID in_typeID) : typeID(in_typeID)
+  {  objID = nextID++; };
 private:
   const TypeID typeID;
+  ObjID objID;
 };
 
 #endif // SCENENODE_HPP
